@@ -42,6 +42,13 @@ class ComputeRestoreConfig(util.RestrictedDict):
         "Metadata",
         "Labels",
         "Tags",
+        "MachineType",
+        "Hostname",
+        "EnableUefiNetworking",
+        "ThreadsPerCore",
+        "VisibleCoreCount",
+        "Accelerator",
+        "MinCpuPlatform",
     ]
     super(ComputeRestoreConfig, self).__init__(supported_flags, *args, **kwargs)
 
@@ -160,6 +167,58 @@ class BackupsClient(util.BackupDrClientBase):
       if tags_message:
         restore_request.computeInstanceRestoreProperties.tags = tags_message
 
+    # Machine Type
+    if "MachineType" in restore_config:
+      restore_request.computeInstanceRestoreProperties.machineType = (
+          restore_config["MachineType"]
+      )
+
+    # Hostname
+    if "Hostname" in restore_config:
+      restore_request.computeInstanceRestoreProperties.hostname = (
+          restore_config["Hostname"]
+      )
+
+    # AdvancedMachineFeatures
+    # EnableUefiNetworking, ThreadsPerCore, VisibleCoreCount
+    advanced_machine_features_message = (
+        ComputeUtil.ParseAdvancedMachineFeatures(
+            self.messages,
+            restore_config.get("EnableUefiNetworking", None),
+            restore_config.get("ThreadsPerCore", None),
+            restore_config.get("VisibleCoreCount", None),
+        )
+    )
+    if advanced_machine_features_message:
+      restore_request.computeInstanceRestoreProperties.advancedMachineFeatures = (
+          advanced_machine_features_message
+      )
+
+    # Accelerator
+    if "Accelerator" in restore_config:
+      accelerators_message = ComputeUtil.ParseAccelerator(
+          self.messages, restore_config["Accelerator"]
+      )
+      if accelerators_message:
+        restore_request.computeInstanceRestoreProperties.guestAccelerators = (
+            accelerators_message
+        )
+        # Few scheduling properties are needed to be set for using GPUs
+        # TODO: b/342962091 - Remove the following code on
+        # implementing scheduling
+        restore_request.computeInstanceRestoreProperties.scheduling = self.messages.Scheduling(
+            onHostMaintenance=self.messages.Scheduling.OnHostMaintenanceValueValuesEnum(
+                "TERMINATE"
+            ),
+            automaticRestart=True,
+        )
+
+    # MinCpuPlatform
+    if "MinCpuPlatform" in restore_config:
+      restore_request.computeInstanceRestoreProperties.minCpuPlatform = (
+          restore_config["MinCpuPlatform"]
+      )
+
     request = self.messages.BackupdrProjectsLocationsBackupVaultsDataSourcesBackupsRestoreRequest(
         name=resource.RelativeName(), restoreBackupRequest=restore_request
     )
