@@ -79,8 +79,8 @@ class DatabaseInstancePresentation(object):
 def GetRegionFromZone(gce_zone):
   """Parses and returns the region string from the gce_zone string."""
   zone_components = gce_zone.split('-')
-  # The region is the first two components of the zone.
-  return '-'.join(zone_components[:2])
+  # The region is all but the last component of the zone.
+  return '-'.join(zone_components[:-1])
 
 
 def _IsCloudSqlProxyPresentInSdkBin(cloud_sql_proxy_path):
@@ -211,14 +211,6 @@ def StartCloudSqlProxy(instance, port, seconds_to_timeout=10):
   return _WaitForProxyToStart(proxy_process, port, seconds_to_timeout)
 
 
-def IsInstanceV1(sql_messages, instance):
-  """Returns a boolean indicating if the database instance is first gen."""
-  return (instance.backendType ==
-          sql_messages.DatabaseInstance.BackendTypeValueValuesEnum.FIRST_GEN or
-          (instance.settings and instance.settings.tier and
-           instance.settings.tier.startswith('D')))
-
-
 def IsInstanceV2(sql_messages, instance):
   """Returns a boolean indicating if the database instance is second gen."""
   return instance.backendType == sql_messages.DatabaseInstance.BackendTypeValueValuesEnum.SECOND_GEN
@@ -277,6 +269,15 @@ class _BaseInstances(object):
         default=True,
         cancel_on_no=True)
 
+  @staticmethod
+  def PrintAndConfirmSimulatedMaintenanceEvent():
+    console_io.PromptContinue(
+        message='This request will trigger a simulated maintenance event '
+        'and will not change the maintenance version on the instance. Downtime '
+        'will occur on the instance.',
+        default=False,
+        cancel_on_no=True)
+
   @staticmethod
   def IsMysqlDatabaseVersion(database_version):
     """Returns a boolean indicating if the database version is MySQL."""
