@@ -38,12 +38,24 @@ def AddUpdateMaskForSubnets(_, args, request):
     return request
 
   subnet_update_mask = "gcpConfig.accessConfig.networkConfigs"
-  request.updateMask = subnet_update_mask if not request.updateMask else (
-      request.updateMask + "," + subnet_update_mask
-  )
+  request.updateMask = AppendUpdateMask(request.updateMask, subnet_update_mask)
   return MapSubnetsToNetworkConfig(_, args, request)
 
 
+def AppendUpdateMask(update_mask, new_mask):
+  """Handles appending a new mask to an existing mask.
+
+  Args:
+    update_mask: the existing update mask.
+    new_mask: the new mask to append.
+
+  Returns:
+    The fully appended update mask.
+  """
+  update_mask = f"{update_mask},{new_mask}"
+  return update_mask if update_mask[0] != "," else update_mask[1:]
+
+
 def MapSubnetsToNetworkConfig(_, args, request):
   """Maps the list of subnets from the flag to the API fields in the request.
 
@@ -113,8 +125,11 @@ def SynthesizeBootstrapAddr(response, cluster):
   name = cluster.split("/")[5]
   location = cluster.split("/")[3]
   project = core.properties.VALUES.core.project.Get()
+  domain_prefixed_project = project.split(":")
+  if len(domain_prefixed_project) == 2:
+    project = f"{domain_prefixed_project[1]}.{domain_prefixed_project[0]}"
   bootstrap = (
-      f"bootstrap.{name}.{location}.managedkafka.{project}.cloud.goog:9092"
+      f"bootstrap.{name}.{location}.managedkafka.{project}.cloud.goog"
   )
   synthesized = core.resource.resource_projector.MakeSerializable(response)
   synthesized["bootstrapAddress"] = bootstrap
@@ -140,3 +155,26 @@ def UpdateTopics(_, args, request):
   }
   request.updateMask = "topics"
   return request
+
+
+def PatchConfigs(_, args, request):
+  """Unnest the configs dictionary to the update mask.
+
+  Args:
+    _:  resource parameter required but unused variable.
+    args: list of flags.
+    request:  the payload to return.
+
+  Returns:
+    The new update mask with the configs.
+  """
+  if args.configs:
+    update_mask = request.updateMask.split(",")
+    update_mask.remove("configs")
+    configs_list = []
+    for key, _ in args.configs.items():
+      configs_list.append(f'configs["{key}"]')
+    request.updateMask = AppendUpdateMask(
+        ",".join(update_mask), ",".join(configs_list)
+    )
+  return request
