@@ -442,6 +442,9 @@ class _BaseInstances(object):
     if args.enable_google_ml_integration is not None:
       settings.enableGoogleMlIntegration = args.enable_google_ml_integration
 
+    if args.enable_dataplex_integration is not None:
+      settings.enableDataplexIntegration = args.enable_dataplex_integration
+
     # BETA args.
     if IsBetaOrNewer(release_track):
       if args.IsSpecified('storage_auto_increase_limit'):
