@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -308,13 +308,14 @@ initial=0.1,maximum=60.0,multiplier=1.3,                predicate=retries.if_exc
             timeout: Union[float, object] = gapic_v1.method.DEFAULT,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> logging.WriteLogEntriesResponse:
-        r"""Writes log entries to Logging. This API method is the
-        only way to send log entries to Logging. This method is
-        used, directly or indirectly, by the Logging agent
-        (fluentd) and all logging libraries configured to use
-        Logging. A single request may contain log entries for a
-        maximum of 1000 different resources (projects,
-        organizations, billing accounts or folders)
+        r"""Writes log entries to Logging. This API method is the only way
+        to send log entries to Logging. This method is used, directly or
+        indirectly, by the Logging agent (fluentd) and all logging
+        libraries configured to use Logging. A single request may
+        contain log entries for a maximum of 1000 different resource
+        names (projects, organizations, billing accounts or folders),
+        where the resource name for a log entry is determined from its
+        ``logName`` field.
 
         .. code-block:: python
 
@@ -574,6 +575,12 @@ initial=0.1,maximum=60.0,multiplier=1.3,                predicate=retries.if_exc
                 cause the filter to return no results. The maximum
                 length of a filter is 20,000 characters.
 
+                To make queries faster, you can make the filter more
+                selective by using restrictions on [indexed fields]
+                (https://cloud.google.com/logging/docs/view/logging-query-language#indexed-fields)
+                as well as limit the time range of the query by adding
+                range restrictions on the ``timestamp`` field.
+
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -587,6 +594,12 @@ initial=0.1,maximum=60.0,multiplier=1.3,                predicate=retries.if_exc
                 (newest first). Entries with equal timestamps are
                 returned in order of their ``insert_id`` values.
 
+                We recommend setting the ``order_by`` field to
+                ``"timestamp desc"`` when listing recently ingested log
+                entries. If not set, the default value of
+                ``"timestamp asc"`` may take a long time to fetch
+                matching logs that are only recently ingested.
+
                 This corresponds to the ``order_by`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -815,6 +828,7 @@ initial=0.1,maximum=60.0,multiplier=1.3,                predicate=retries.if_exc
         Returns:
             googlecloudsdk.generated_clients.gapic_clients.logging_v2.services.logging_service_v2.pagers.ListLogsAsyncPager:
                 Result returned from ListLogs.
+
                 Iterating over this object will yield
                 results and resolve additional pages
                 automatically.
@@ -968,7 +982,7 @@ initial=0.1,maximum=60.0,multiplier=1.3,                predicate=retries.if_exc
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "LoggingServiceV2AsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
