@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,12 +21,20 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
+@base.UniverseCompatible
 class Regions(base.Group):
-  """List Google Compute Engine regions."""
+  """List Compute Engine regions."""
 
 
-Regions.category = base.COMPUTE_INFO_CATEGORY
+Regions.category = base.INFO_CATEGORY
 
 Regions.detailed_help = {
-    'brief': 'List Google Compute Engine regions',
+    'DESCRIPTION': """
+        List Compute Engine regions.
+
+        For more information about regions, see the
+        [regions documentation](https://cloud.google.com/compute/docs/regions-zones/).
+
+        See also: [Regions API](https://cloud.google.com/compute/docs/reference/rest/v1/regions).
+    """,
 }
