@@ -33,6 +33,7 @@ def _CommonArgs(parser, api_version=filestore_client.V1_API_VERSION):
   instances_flags.AddInstanceCreateArgs(parser, api_version)
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class Create(base.CreateCommand):
   """Create a Filestore instance."""
@@ -46,7 +47,7 @@ class Create(base.CreateCommand):
           """\
     The following command creates a Filestore instance named NAME with a single volume.
 
-      $ {command} NAME --description=DESCRIPTION --tier=TIER --file-share=name=VOLUME_NAME,capacity=CAPACITY --network=name=NETWORK_NAME,reserved-ip-range=RESERVED_IP_RANGE,connect-mode=CONNECT_MODE --zone=ZONE --kms-key=KMS-KEY --kms-keyring=KMS_KEYRING --kms-location=KMS_LOCATION --kms-project=KMS_PROJECT --flags-file=FLAGS_FILE
+      $ {command} NAME --description=DESCRIPTION --tier=TIER --file-share=name=VOLUME_NAME,capacity=CAPACITY --network=name=NETWORK_NAME,reserved-ip-range=RESERVED_IP_RANGE,connect-mode=CONNECT_MODE --zone=ZONE --kms-key=KMS-KEY --kms-keyring=KMS_KEYRING --kms-location=KMS_LOCATION --kms-project=KMS_PROJECT --flags-file=FLAGS_FILE --source-instance=SOURCE_INSTANCE
 
     Example json configuration file:
   {
@@ -86,9 +87,9 @@ class Create(base.CreateCommand):
     """Create a Filestore instance in the current project."""
     instance_ref = args.CONCEPTS.instance.Parse()
     client = filestore_client.FilestoreClient(self._API_VERSION)
-    tier = instances_flags.GetTierArg(
-        client.messages, self._API_VERSION
-    ).GetEnumForChoice(args.tier)
+    tier = instances_flags.GetTierArg(client.messages).GetEnumForChoice(
+        args.tier
+    )
     labels = labels_util.ParseCreateArgs(args,
                                          client.messages.Instance.LabelsValue)
     try:
@@ -106,7 +107,8 @@ class Create(base.CreateCommand):
         labels=labels,
         zone=instance_ref.locationsId,
         nfs_export_options=nfs_export_options,
-        kms_key_name=instances_flags.GetAndValidateKmsKeyName(args))
+        kms_key_name=instances_flags.GetAndValidateKmsKeyName(args),
+        source_instance=args.source_instance)
     result = client.CreateInstance(instance_ref, args.async_, instance)
     if args.async_:
       command = properties.VALUES.metrics.command_name.Get().split('.')
@@ -118,6 +120,7 @@ class Create(base.CreateCommand):
     return result
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
 class CreateBeta(Create):
   """Create a Filestore instance."""
@@ -131,7 +134,7 @@ class CreateBeta(Create):
           """\
     The following command creates a Filestore instance named NAME with a single volume.
 
-      $ {command} NAME --description=DESCRIPTION --tier=TIER --protocol=PROTOCOL --file-share=name=VOLUME_NAME,capacity=CAPACITY --network=name=NETWORK_NAME,reserved-ip-range=RESERVED_IP_RANGE,connect-mode=CONNECT_MODE --zone=ZONE --kms-key=KMS-KEY --kms-keyring=KMS_KEYRING --kms-location=KMS_LOCATION --kms-project=KMS_PROJECT --managed-ad=domain=DOMAIN,computer=COMPUTER --flags-file=FLAGS_FILE
+      $ {command} NAME --description=DESCRIPTION --tier=TIER --protocol=PROTOCOL --file-share=name=VOLUME_NAME,capacity=CAPACITY --network=name=NETWORK_NAME,reserved-ip-range=RESERVED_IP_RANGE,connect-mode=CONNECT_MODE --zone=ZONE --kms-key=KMS-KEY --kms-keyring=KMS_KEYRING --kms-location=KMS_LOCATION --kms-project=KMS_PROJECT --managed-ad=domain=DOMAIN,computer=COMPUTER --flags-file=FLAGS_FILE --source-instance=SOURCE_INSTANCE
 
     Example json configuration file:
   {
@@ -178,18 +181,20 @@ class CreateBeta(Create):
     """
     instance_ref = args.CONCEPTS.instance.Parse()
     client = filestore_client.FilestoreClient(self._API_VERSION)
-    tier = instances_flags.GetTierArg(
-        client.messages, self._API_VERSION
-    ).GetEnumForChoice(args.tier)
+    tier = instances_flags.GetTierArg(client.messages).GetEnumForChoice(
+        args.tier
+    )
     protocol = None
     if args.protocol is not None:
-      protocol = instances_flags.GetProtocolArg(client.messages
+      protocol = instances_flags.GetProtocolArg(
+          client.messages
       ).GetEnumForChoice(args.protocol)
     managed_ad = args.managed_ad or None
+    source_instance = args.source_instance or None
     labels = labels_util.ParseCreateArgs(
         args, client.messages.Instance.LabelsValue)
     try:
-      nfs_export_options = client.MakeNFSExportOptionsMsg(
+      nfs_export_options = client.MakeNFSExportOptionsMsgBeta(
           messages=client.messages,
           nfs_export_options=args.file_share.get('nfs-export-options', []))
     except KeyError as err:
@@ -205,7 +210,8 @@ class CreateBeta(Create):
         zone=instance_ref.locationsId,
         nfs_export_options=nfs_export_options,
         kms_key_name=instances_flags.GetAndValidateKmsKeyName(args),
-        managed_ad=managed_ad)
+        managed_ad=managed_ad,
+        source_instance=source_instance)
 
     result = client.CreateInstance(instance_ref, args.async_, instance)
     if args.async_:
@@ -217,6 +223,7 @@ class CreateBeta(Create):
           '$ {} '.format(' '.join(command)))
     return result
 
+
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class CreateAlpha(Create):
   """Create a Filestore instance."""
@@ -275,9 +282,9 @@ class CreateAlpha(Create):
     """Create a Filestore instance in the current project."""
     instance_ref = args.CONCEPTS.instance.Parse()
     client = filestore_client.FilestoreClient(self._API_VERSION)
-    tier = instances_flags.GetTierArg(
-        client.messages, self._API_VERSION
-    ).GetEnumForChoice(args.tier)
+    tier = instances_flags.GetTierArg(client.messages).GetEnumForChoice(
+        args.tier
+    )
     labels = labels_util.ParseCreateArgs(args,
                                          client.messages.Instance.LabelsValue)
     try:
