@@ -24,10 +24,11 @@ from googlecloudsdk.command_lib.network_security import flags
 from googlecloudsdk.command_lib.network_security import util
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class ListReferences(base.ListCommand):
   """Lists References of an Address Group."""
-  _release_track = base.ReleaseTrack.BETA
+  _release_track = base.ReleaseTrack.GA
 
   detailed_help = {
       'EXAMPLES':
@@ -41,12 +42,24 @@ class ListReferences(base.ListCommand):
   @classmethod
   def Args(cls, parser):
     flags.AddProjectAddressGroupToParser(cls._release_track, parser)
-    flags.AddListReferencesFormat(parser)
+    if cls._release_track == base.ReleaseTrack.GA:
+      flags.AddListReferencesFormat(parser)
+    else:
+      flags.AddListReferencesBetaFormat(parser)
 
   def Run(self, args):
     return util.ListProjectAddressGroupReferences(self._release_track, args)
 
 
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class ListReferencesBeta(ListReferences):
+  """Lists References of an Address Group."""
+  _release_track = base.ReleaseTrack.BETA
+
+
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class ListReferencesAlpha(ListReferences):
   """Lists References of an Address Group."""
+  _release_track = base.ReleaseTrack.ALPHA
