@@ -36,11 +36,7 @@ def _GetUriFromResource(resource):
   ).SelfLink()
 
 
-def AddBetaArgs(parser):
-  """Adds base args and flags to the parser."""
-  flags.AddShowSqlNetworkArchitecture(parser)
-
-
+@base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class List(base.ListCommand):
   """Lists Cloud SQL instances in a given project.
@@ -53,6 +49,8 @@ class List(base.ListCommand):
   def Args(parser):
     parser.display_info.AddFormat(flags.GetInstanceListFormat())
     parser.display_info.AddUriFunc(_GetUriFromResource)
+    flags.AddShowEdition(parser)
+    flags.AddShowSqlNetworkArchitecture(parser)
 
   def Run(self, args):
     """Lists Cloud SQL instances in a given project.
@@ -64,11 +62,18 @@ class List(base.ListCommand):
     Returns:
       SQL instance resource iterator.
     """
+    if args.show_edition:
+      args.GetDisplayInfo().AddFormat(flags.GetInstanceListFormatEdition())
+    if args.show_sql_network_architecture:
+      args.GetDisplayInfo().AddFormat(
+          flags.GetInstanceListFormatForNetworkArchitectureUpgrade()
+      )
     return instances.InstancesV1Beta4.GetDatabaseInstances(
         limit=args.limit, batch_size=args.page_size
     )
 
 
+@base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class ListBeta(base.ListCommand):
   """Lists Cloud SQL instances in a given project.
@@ -80,9 +85,11 @@ class ListBeta(base.ListCommand):
   @staticmethod
   def Args(parser):
     """Args is called by calliope to gather arguments for this command."""
-    AddBetaArgs(parser)
     parser.display_info.AddFormat(flags.GetInstanceListFormat())
     parser.display_info.AddUriFunc(_GetUriFromResource)
+    flags.AddShowEdition(parser)
+    flags.AddShowSqlNetworkArchitecture(parser)
+    flags.AddShowTransactionalLogStorageState(parser)
 
   def Run(self, args):
     """Lists Cloud SQL instances in a given project.
@@ -94,10 +101,16 @@ class ListBeta(base.ListCommand):
     Returns:
       SQL instance resource iterator.
     """
+    if args.show_edition:
+      args.GetDisplayInfo().AddFormat(flags.GetInstanceListFormatEdition())
     if args.show_sql_network_architecture:
       args.GetDisplayInfo().AddFormat(
           flags.GetInstanceListFormatForNetworkArchitectureUpgrade()
       )
+    if args.show_transactional_log_storage_state:
+      args.GetDisplayInfo().AddFormat(
+          flags.GetInstanceListFormatForTransactionalLogStorageSwitch()
+      )
     return instances.InstancesV1Beta4.GetDatabaseInstances(
         limit=args.limit, batch_size=args.page_size
     )
